@@ -5,14 +5,20 @@
 # --------------------------------------------------------------------
 
 import functools
+import re
 from typing import Union
 
-from hexbytes import HexBytes
-
+from eth_abi import (
+    encode_abi as eth_abi_encode_abi,
+)
+from eth_abi.exceptions import (
+    EncodingError,
+)
 from eth_utils import (
     to_hex,
     function_abi_to_4byte_selector
 )
+from hexbytes import HexBytes
 from trx_utils import is_text, encode_hex
 from trx_utils.typing import HexStr
 
@@ -27,7 +33,6 @@ from tronpytool.common.abi import (
     map_abi_data,
     merge_args_and_kwargs
 )
-
 from tronpytool.common.normalizers import (
     abi_address_to_hex,
     abi_bytes_to_bytes,
@@ -37,19 +42,32 @@ from tronpytool.common.toolz import (
     pipe,
     valmap,
 )
-from eth_abi import (
-    encode_abi as eth_abi_encode_abi,
-)
-
-from eth_abi.exceptions import (
-    EncodingError,
-)
 
 
 class FallbackFn:
     pass
 
 
+def find_match_tron_address(test_str: str) -> str:
+    regex = r"\T.[a-zA-Z0-9]{32}"
+
+    matches = re.search(regex, test_str)
+
+    if matches:
+        print("Match was found at {start}-{end}: {match}".format(start=matches.start(), end=matches.end(),
+                                                                 match=matches.group()))
+
+        for groupNum in range(0, len(matches.groups())):
+            groupNum = groupNum + 1
+
+            print("Group {groupNum} found at {start}-{end}: {group}".format(groupNum=groupNum,
+                                                                            start=matches.start(groupNum),
+                                                                            end=matches.end(groupNum),
+                                                                            group=matches.group(groupNum)))
+
+    return matches
+
+
 def find_matching_fn_abi(abi, fn_identifier=None, args=None, kwargs=None):
     args = args or tuple()
     kwargs = kwargs or dict()
