@@ -12,30 +12,30 @@
 from .providers.http import HttpProvider
 
 DEFAULT_NODES = {
-    'full_node': 'https://api.trongrid.io',
-    'solidity_node': 'https://api.trongrid.io',
-    'event_server': 'https://api.trongrid.io'
+    "full_node": "https://api.trongrid.io",
+    "solidity_node": "https://api.trongrid.io",
+    "event_server": "https://api.trongrid.io"
 }
 
 CONF_MAINNET = {
     "full_node": "https://api.trongrid.io",
     "event_server": "https://api.trongrid.io",
-    'solidity_node': 'https://api.trongrid.io',
+    "solidity_node": "https://api.trongrid.io",
 }
 
 # The long running, maintained by the tron-us community
 CONF_SHASTA = {
     "full_node": "https://api.shasta.trongrid.io",
     "event_server": "https://api.shasta.trongrid.io",
+    "solidity_node": "https://api.shasta.trongrid.io",
     "faucet": "https://www.trongrid.io/faucet",
-    'solidity_node': 'https://api.shasta.trongrid.io',
 }
 
 # Maintained by the official team
 CONF_NILE = {
-    "full_node": "https://httpapi.nileex.io",
-    "event_server": "https://eventtest.nileex.io",
-    "solidity_node": "https://httpapi.nileex.io",
+    "full_node": "https://api.nileex.io",
+    "event_server": "https://event.nileex.io",
+    "solidity_node": "https://api.nileex.io",
     "faucet": "http://nileex.io/join/getJoinPage",
 }
 
@@ -43,7 +43,7 @@ CONF_NILE = {
 CONF_TRONEX = {
     "full_node": "https://testhttpapi.tronex.io",
     "event_server": "https://testapi.tronex.io",
-    'solidity_node': 'https://testapi.tronex.io',
+    "solidity_node": "https://testapi.tronex.io",
     "faucet": "http://testnet.tronex.io/join/getJoinPage",
 }
 
